#ifndef _SYNCML_PLUGIN_DS_SERVER_H
#define _SYNCML_PLUGIN_DS_SERVER_H

#include "syncml_common.h"

void ds_server_get_changeinfo(
         OSyncObjTypeSink *sink,
         OSyncPluginInfo *info,
         OSyncContext *ctx,
         osync_bool slow_sync,
         void *data);

void ds_server_commit(
         OSyncObjTypeSink *sink,
         OSyncPluginInfo *info,
         OSyncContext *ctx,
         OSyncChange *change,
         void *data);

void ds_server_committed_all(
         OSyncObjTypeSink *sink,
         OSyncPluginInfo *info,
         OSyncContext *ctx,
         void *data);

SmlBool ds_server_init_databases(
            SmlPluginEnv *env,
            OSyncPluginInfo *info,
            OSyncError **error);

#endif //_SYNCML_PLUGIN_DS_SERVER_H
